@@ -3,7 +3,7 @@ import autograd.numpy as np
 import copy
 from scipy.optimize import minimize
 
-from cwgp.kernel import RBF, OU
+from cwgp.kernel import RBF, OU, Matern32
 from cwgp.transformations import sal, sa, asinh, box_cox, inv_sal, inv_sa, inv_asinh, inv_box_cox
 
 
@@ -16,8 +16,9 @@ class Phi():
     }
 
     KERNEL_BANK = {
-        "OU": {"kern": OU, "params": 1},
-        "RBF": {"kern": RBF, "params": 1},
+        "OU": {"kern": OU, "params": 1, "init_scale": 1},
+        "RBF": {"kern": RBF, "params": 1, "init_scale": 10},
+        "Matern32": {"kern": Matern32, "params": 2, "init_scale": 10},
     }
 
     def __init__(
@@ -33,6 +34,7 @@ class Phi():
         self.kernel = self.KERNEL_BANK[kernel]["kern"]
         self.kernel_params = self.KERNEL_BANK[kernel]["params"] if kernel_params_estimate else 0
         self.par_len = self.FN_BANK[fn]["par_len"]
+        self.init_scale = self.KERNEL_BANK[kernel]["init_scale"]
         self.n = n
 
     def comp_phi(self, par, y):
@@ -65,7 +67,6 @@ class Phi():
         else:
             cov_xx = self.kernel(phi_y, t_phi_y)
         gaussian_params = 0.5 * (t_phi_y) @ np.linalg.inv(cov_xx) @ phi_y
-
         return np.ravel(0.5 * np.log(np.linalg.det(cov_xx)) +
                         gaussian_params - sum(np.log(chain_d_sal)))
 
@@ -81,7 +82,7 @@ class Phi():
                 try:
                     res = minimize(
                         self.likelihood,
-                        np.random.rand(
+                        self.init_scale * np.random.rand(
                             self.par_len *
                             self.n +
                             self.kernel_params),
